#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-yaml
version:              1.1.0.0
visibility:           public
id:                   aeson-yaml-1.1.0.0-KmV7UBgPjsJ2ycjz5uV7ud
key:                  aeson-yaml-1.1.0.0-KmV7UBgPjsJ2ycjz5uV7ud
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  6f547bc68d254fb37fb8ff9729246143
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-8.10.2/site-local/aeson-yaml-1.1.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/aeson-yaml-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/aeson-yaml-1.1.0.0
hs-libraries:         HSaeson-yaml-1.1.0.0-KmV7UBgPjsJ2ycjz5uV7ud
depends:
    aeson-1.5.5.1-7ZKmq9KLIncxnBfAj9HU2 base-4.14.1.0
    bytestring-0.10.10.0 text-1.2.3.2
    unordered-containers-0.2.13.0-HeBOjfSts31GSj9apQxnyX
    vector-0.12.1.2-IO5RJnkQnAxDAG50LdixTd

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

